.. _api-entity:

Entity
------

Lifecycle Methods:
~~~~~~~~~~~~~~~~~~

.. _api-entity-save:

``save()``
^^^^^^^^^^

.. automethod:: protean.core.entity.Entity.save

.. _api-entity-get:

``get()``
^^^^^^^^^

.. automethod:: protean.core.entity.Entity.get

.. _api-entity-update:

``update()``
^^^^^^^^^^^^

.. automethod:: protean.core.entity.Entity.update

.. _api-entity-delete:

``delete()``
^^^^^^^^^^^^

.. automethod:: protean.core.entity.Entity.delete

Other Methods:
~~~~~~~~~~~~~~

.. _api-entity-exists:

``exists()``
^^^^^^^^^^^^

.. automethod:: protean.core.entity.Entity.exists

.. _api-entity-find-by:

``find_by()``
^^^^^^^^^^^^^

.. automethod:: protean.core.entity.Entity.find_by

